==> qtjambi-sql-debuginfo-linux-x64-5.15.18.jar: sources/QtJambiSql/QSqlTableModel_shell.h <==
#ifndef QSQLTABLEMODEL_SHELL_H
#define QSQLTABLEMODEL_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <qtsql-config.h>
#if QT_CONFIG(sqlmodel)
#include <QtSql/qsqltablemodel.h>
#endif //QT_CONFIG(sqlmodel)
#include <QtJambi/QtJambiAPI>
#include <QSize>
#include <QSqlIndex>
#include <QStringList>
#include <QtCore/QHash>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtCore/QVector>
#include <qtcore-config.h>
#if QT_CONFIG(itemmodel)
#include <QtCore/qabstractitemmodel.h>
#endif //QT_CONFIG(itemmodel)
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qdatastream.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qmimedata.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qsize.h>
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtSql/qsqldatabase.h>
#include <QtSql/qsqlerror.h>
#include <QtSql/qsqlindex.h>
#include <QtSql/qsqlquery.h>
#include <QtSql/qsqlrecord.h>
#include <QtJambi/RegistryAPI>


#if QT_CONFIG(sqlmodel)

class QSqlTableModel_shell : public QSqlTableModel, public QtJambiShellInterface
{
public:
    QSqlTableModel_shell(QObject* parent0 = nullptr, QSqlDatabase db1 = QSqlDatabase());
    ~QSqlTableModel_shell() override;

    QModelIndex buddy(const QModelIndex& index0) const override;
    bool canDropMimeData(const QMimeData* data0, Qt::DropAction action1, int row2, int column3, const QModelIndex& parent4) const override;
    bool canFetchMore(const QModelIndex& parent0) const override;
    void childEvent(QChildEvent* event0) override;
    void clear() override;
    int columnCount(const QModelIndex& parent0) const override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    QVariant data(const QModelIndex& idx0, int role1) const override;
    bool deleteRowFromTable(int row0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool dropMimeData(const QMimeData* data0, Qt::DropAction action1, int row2, int column3, const QModelIndex& parent4) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void fetchMore(const QModelIndex& parent0) override;
    Qt::ItemFlags flags(const QModelIndex& index0) const override;
    QVariant headerData(int section0, Qt::Orientation orientation1, int role2) const override;
    QModelIndex index(int row0, int column1, const QModelIndex& parent2) const override;
    QModelIndex indexInQuery(const QModelIndex& item0) const override;
    bool insertColumns(int column0, int count1, const QModelIndex& parent2) override;
    bool insertRowIntoTable(const QSqlRecord& values0) override;
    bool insertRows(int row0, int count1, const QModelIndex& parent2) override;
    QMap<int, QVariant> itemData(const QModelIndex& index0) const override;
    QList<QModelIndex> match(const QModelIndex& start0, int role1, const QVariant& value2, int hits3, Qt::MatchFlags flags4) const override;
    QMimeData* mimeData(const QList<QModelIndex>& indexes0) const override;
    QStringList mimeTypes() const override;
    bool moveColumns(const QModelIndex& sourceParent0, int sourceColumn1, int count2, const QModelIndex& destinationParent3, int destinationChild4) override;
    bool moveRows(const QModelIndex& sourceParent0, int sourceRow1, int count2, const QModelIndex& destinationParent3, int destinationChild4) override;
    QString orderByClause() const override;
    void queryChange() override;
    bool removeColumns(int column0, int count1, const QModelIndex& parent2) override;
    bool removeRows(int row0, int count1, const QModelIndex& parent2) override;
    void revert() override;
    void revertRow(int row0) override;
    QHash<int, QByteArray> roleNames() const override;
    int rowCount(const QModelIndex& parent0) const override;
    bool select() override;
    bool selectRow(int row0) override;
    QString selectStatement() const override;
    bool setData(const QModelIndex& index0, const QVariant& value1, int role2) override;
    void setEditStrategy(QSqlTableModel::EditStrategy strategy0) override;
    void setFilter(const QString& filter0) override;
    bool setHeaderData(int section0, Qt::Orientation orientation1, const QVariant& value2, int role3) override;
    bool setItemData(const QModelIndex& index0, const QMap<int, QVariant>& roles1) override;
    void setSort(int column0, Qt::SortOrder order1) override;
    void setTable(const QString& tableName0) override;
    QModelIndex sibling(int row0, int column1, const QModelIndex& idx2) const override;
    void sort(int column0, Qt::SortOrder order1) override;
    QSize span(const QModelIndex& index0) const override;
    bool submit() override;
    Qt::DropActions supportedDragActions() const override;
    Qt::DropActions supportedDropActions() const override;
    void timerEvent(QTimerEvent* event0) override;
    bool updateRowInTable(int row0, const QSqlRecord& values1) override;
    void resetInternalData();
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QSqlTableModel_access : public QSqlTableModel
{
    jobject __qt_primaryValues_int_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint row0) const;
    void __qt_setPrimaryKey_cref_QSqlIndex(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID key0);
    void __qt_clear(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jobject __qt_data_cref_QModelIndex_int_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID idx0, jint role1) const;
    jboolean __qt_deleteRowFromTable_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint row0);
    jint __qt_flags_cref_QModelIndex_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID index0) const;
    jobject __qt_headerData_int_Qt_Orientation_int_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint section0, jint orientation1, jint role2) const;
    jobject __qt_indexInQuery_cref_QModelIndex_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID item0) const;
    jboolean __qt_insertRowIntoTable_cref_QSqlRecord(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID values0);
    jboolean __qt_insertRows_int_int_cref_QModelIndex(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint row0, jint count1, QtJambiNativeID parent2);
    jstring __qt_orderByClause(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_removeColumns_int_int_cref_QModelIndex(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint column0, jint count1, QtJambiNativeID parent2);
    jboolean __qt_removeRows_int_int_cref_QModelIndex(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint row0, jint count1, QtJambiNativeID parent2);
    void __qt_revert(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    void __qt_revertRow_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint row0);
    jint __qt_rowCount_cref_QModelIndex_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID parent0) const;
    jboolean __qt_select(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jboolean __qt_selectRow_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint row0);
    jstring __qt_selectStatement(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_setData_cref_QModelIndex_cref_QVariant_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID index0, jobject value1, jint role2);
    void __qt_setEditStrategy_QSqlTableModel_EditStrategy(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint strategy0);
    void __qt_setFilter_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring filter0);
    void __qt_setSort_int_Qt_SortOrder(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint column0, jint order1);
    void __qt_setTable_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring tableName0);
    void __qt_sort_int_Qt_SortOrder(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint column0, jint order1);
    jboolean __qt_submit(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jboolean __qt_updateRowInTable_int_cref_QSqlRecord(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint row0, QtJambiNativeID values1);
};

#endif // QT_CONFIG(sqlmodel)
#endif // QSQLTABLEMODEL_SHELL_H

==> qtjambi-sql-debuginfo-linux-x64-5.15.20.jar: sources/QtJambiSql/QSqlTableModel_shell.h <==
#ifndef QSQLTABLEMODEL_SHELL_H
#define QSQLTABLEMODEL_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <qtsql-config.h>
#if QT_CONFIG(sqlmodel)
#include <QtSql/qsqltablemodel.h>
#endif //QT_CONFIG(sqlmodel)
#include <QtJambi/QtJambiAPI>
#include <QSize>
#include <QSqlIndex>
#include <QStringList>
#include <QtCore/QHash>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtCore/QVector>
#include <qtcore-config.h>
#if QT_CONFIG(itemmodel)
#include <QtCore/qabstractitemmodel.h>
#endif //QT_CONFIG(itemmodel)
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qdatastream.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qmimedata.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qsize.h>
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtSql/qsqldatabase.h>
#include <QtSql/qsqlerror.h>
#include <QtSql/qsqlindex.h>
#include <QtSql/qsqlquery.h>
#include <QtSql/qsqlrecord.h>
#include <QtJambi/RegistryAPI>


#if QT_CONFIG(sqlmodel)

class QSqlTableModel_shell : public QSqlTableModel, public QtJambiShellInterface
{
public:
    QSqlTableModel_shell(QObject* parent0 = nullptr, QSqlDatabase db1 = QSqlDatabase());
    ~QSqlTableModel_shell() override;

    QModelIndex buddy(const QModelIndex& index0) const override;
    bool canDropMimeData(const QMimeData* data0, Qt::DropAction action1, int row2, int column3, const QModelIndex& parent4) const override;
    bool canFetchMore(const QModelIndex& parent0) const override;
    void childEvent(QChildEvent* event0) override;
    void clear() override;
    int columnCount(const QModelIndex& parent0) const override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    QVariant data(const QModelIndex& idx0, int role1) const override;
    bool deleteRowFromTable(int row0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool dropMimeData(const QMimeData* data0, Qt::DropAction action1, int row2, int column3, const QModelIndex& parent4) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void fetchMore(const QModelIndex& parent0) override;
    Qt::ItemFlags flags(const QModelIndex& index0) const override;
    QVariant headerData(int section0, Qt::Orientation orientation1, int role2) const override;
    QModelIndex index(int row0, int column1, const QModelIndex& parent2) const override;
    QModelIndex indexInQuery(const QModelIndex& item0) const override;
    bool insertColumns(int column0, int count1, const QModelIndex& parent2) override;
    bool insertRowIntoTable(const QSqlRecord& values0) override;
    bool insertRows(int row0, int count1, const QModelIndex& parent2) override;
    QMap<int, QVariant> itemData(const QModelIndex& index0) const override;
    QList<QModelIndex> match(const QModelIndex& start0, int role1, const QVariant& value2, int hits3, Qt::MatchFlags flags4) const override;
    QMimeData* mimeData(const QList<QModelIndex>& indexes0) const override;
    QStringList mimeTypes() const override;
    bool moveColumns(const QModelIndex& sourceParent0, int sourceColumn1, int count2, const QModelIndex& destinationParent3, int destinationChild4) override;
    bool moveRows(const QModelIndex& sourceParent0, int sourceRow1, int count2, const QModelIndex& destinationParent3, int destinationChild4) override;
    QString orderByClause() const override;
    void queryChange() override;
    bool removeColumns(int column0, int count1, const QModelIndex& parent2) override;
    bool removeRows(int row0, int count1, const QModelIndex& parent2) override;
    void revert() override;
    void revertRow(int row0) override;
    QHash<int, QByteArray> roleNames() const override;
    int rowCount(const QModelIndex& parent0) const override;
    bool select() override;
    bool selectRow(int row0) override;
    QString selectStatement() const override;
    bool setData(const QModelIndex& index0, const QVariant& value1, int role2) override;
    void setEditStrategy(QSqlTableModel::EditStrategy strategy0) override;
    void setFilter(const QString& filter0) override;
    bool setHeaderData(int section0, Qt::Orientation orientation1, const QVariant& value2, int role3) override;
    bool setItemData(const QModelIndex& index0, const QMap<int, QVariant>& roles1) override;
    void setSort(int column0, Qt::SortOrder order1) override;
    void setTable(const QString& tableName0) override;
    QModelIndex sibling(int row0, int column1, const QModelIndex& idx2) const override;
    void sort(int column0, Qt::SortOrder order1) override;
    QSize span(const QModelIndex& index0) const override;
    bool submit() override;
    Qt::DropActions supportedDragActions() const override;
    Qt::DropActions supportedDropActions() const override;
    void timerEvent(QTimerEvent* event0) override;
    bool updateRowInTable(int row0, const QSqlRecord& values1) override;
    void resetInternalData();
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QSqlTableModel_access : public QSqlTableModel
{
    jobject __qt_primaryValues_int_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint row0) const;
    void __qt_setPrimaryKey_cref_QSqlIndex(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID key0);
    void __qt_clear(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jobject __qt_data_cref_QModelIndex_int_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID idx0, jint role1) const;
    jboolean __qt_deleteRowFromTable_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint row0);
    jint __qt_flags_cref_QModelIndex_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID index0) const;
    jobject __qt_headerData_int_Qt_Orientation_int_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint section0, jint orientation1, jint role2) const;
    jobject __qt_indexInQuery_cref_QModelIndex_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID item0) const;
    jboolean __qt_insertRowIntoTable_cref_QSqlRecord(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID values0);
    jboolean __qt_insertRows_int_int_cref_QModelIndex(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint row0, jint count1, QtJambiNativeID parent2);
    jstring __qt_orderByClause_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_removeColumns_int_int_cref_QModelIndex(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint column0, jint count1, QtJambiNativeID parent2);
    jboolean __qt_removeRows_int_int_cref_QModelIndex(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint row0, jint count1, QtJambiNativeID parent2);
    void __qt_revert(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    void __qt_revertRow_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint row0);
    jint __qt_rowCount_cref_QModelIndex_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID parent0) const;
    jboolean __qt_select(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jboolean __qt_selectRow_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint row0);
    jstring __qt_selectStatement_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_setData_cref_QModelIndex_cref_QVariant_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID index0, jobject value1, jint role2);
    void __qt_setEditStrategy_QSqlTableModel_EditStrategy(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint strategy0);
    void __qt_setFilter_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring filter0);
    void __qt_setSort_int_Qt_SortOrder(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint column0, jint order1);
    void __qt_setTable_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring tableName0);
    void __qt_sort_int_Qt_SortOrder(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint column0, jint order1);
    jboolean __qt_submit(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jboolean __qt_updateRowInTable_int_cref_QSqlRecord(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint row0, QtJambiNativeID values1);
};

#endif // QT_CONFIG(sqlmodel)
#endif // QSQLTABLEMODEL_SHELL_H
